==> blueprint-component-mapper-3.4.0.tgz: package/esm/wizard/step-buttons.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import selectNext from '@data-driven-forms/common/wizard/select-next';
import clsx from 'clsx';
import { createUseStyles } from 'react-jss';
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";

var NextButton = function NextButton(_ref) {
  var nextStep = _ref.nextStep,
      handleNext = _ref.handleNext,
      buttonLabels = _ref.buttonLabels,
      getState = _ref.getState,
      handleSubmit = _ref.handleSubmit,
      isDisabled = _ref.isDisabled,
      props = _objectWithoutProperties(_ref, ["nextStep", "handleNext", "buttonLabels", "getState", "handleSubmit", "isDisabled"]);

  return /*#__PURE__*/React.createElement(Button, _extends({
    disabled: isDisabled,
    onClick: function onClick() {
      return nextStep ? handleNext(selectNext(nextStep, getState)) : handleSubmit();
    },
    rightIcon: nextStep ? 'arrow-right' : 'arrow-up',
    intent: Intent.SUCCESS
  }, props), nextStep ? buttonLabels.next : buttonLabels.submit);
};

NextButton.propTypes = {
  handleNext: PropTypes.func,
  formOptions: PropTypes.shape({
    onCancel: PropTypes.func,
    renderForm: PropTypes.func,
    getState: PropTypes.func
  }),
  buttonLabels: PropTypes.object,
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.object]),
  getState: PropTypes.func,
  handleSubmit: PropTypes.func,
  isDisabled: PropTypes.bool
};
var useStyles = createUseStyles({
  buttonGroup: {
    marginTop: 16,
    display: 'flex',
    justifyContent: 'space-between',
    '& button:not(:first-child)': {
      marginLeft: 8
    }
  }
});

var StepButtons = function StepButtons(_ref2) {
  var handleNext = _ref2.handleNext,
      currentStep = _ref2.currentStep,
      formOptions = _ref2.formOptions,
      activeStepIndex = _ref2.activeStepIndex,
      buttonLabels = _ref2.buttonLabels,
      handlePrev = _ref2.handlePrev,
      isNextDisabled = _ref2.isNextDisabled,
      ButtonToolbarProps = _ref2.ButtonToolbarProps,
      DirectionButtonProps = _ref2.DirectionButtonProps,
      CancelButtonProps = _ref2.CancelButtonProps,
      BackButtonProps = _ref2.BackButtonProps,
      NextButtonProps = _ref2.NextButtonProps,
      SubmitButtonProps = _ref2.SubmitButtonProps;

  var _useStyles = useStyles(),
      buttonGroup = _useStyles.buttonGroup;

  return /*#__PURE__*/React.createElement("div", _extends({}, ButtonToolbarProps, {
    className: clsx(buttonGroup, ButtonToolbarProps && ButtonToolbarProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    onClick: formOptions.onCancel,
    minimal: true
  }, CancelButtonProps), buttonLabels.cancel), /*#__PURE__*/React.createElement("div", DirectionButtonProps, /*#__PURE__*/React.createElement(Button, _extends({
    onClick: handlePrev,
    disabled: activeStepIndex === 0
  }, BackButtonProps), buttonLabels.back), /*#__PURE__*/React.createElement(NextButton, _extends({
    getState: formOptions.getState,
    nextStep: currentStep.nextStep,
    buttonLabels: buttonLabels,
    handleNext: handleNext,
    isDisabled: !formOptions.valid || isNextDisabled,
    handleSubmit: formOptions.handleSubmit
  }, currentStep.nextStep ? NextButtonProps : SubmitButtonProps))));
};

StepButtons.propTypes = {
  currentStep: PropTypes.object,
  handlePrev: PropTypes.func,
  handleNext: PropTypes.func,
  formOptions: PropTypes.shape({
    onCancel: PropTypes.func,
    renderForm: PropTypes.func,
    getState: PropTypes.func,
    handleSubmit: PropTypes.func,
    valid: PropTypes.bool
  }),
  activeStepIndex: PropTypes.number,
  buttonLabels: PropTypes.object,
  isNextDisabled: PropTypes.bool,
  ButtonToolbarProps: PropTypes.object,
  DirectionButtonProps: PropTypes.object,
  CancelButtonProps: PropTypes.object,
  BackButtonProps: PropTypes.object,
  NextButtonProps: PropTypes.object,
  SubmitButtonProps: PropTypes.object
};
export default StepButtons;

==> blueprint-component-mapper-3.6.0.tgz: package/esm/wizard/step-buttons.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import selectNext from '@data-driven-forms/common/wizard/select-next';
import clsx from 'clsx';
import { createUseStyles } from 'react-jss';
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { Intent } from "@blueprintjs/core/lib/esm/common/intent.js";

var NextButton = function NextButton(_ref) {
  var nextStep = _ref.nextStep,
      handleNext = _ref.handleNext,
      buttonLabels = _ref.buttonLabels,
      getState = _ref.getState,
      handleSubmit = _ref.handleSubmit,
      isDisabled = _ref.isDisabled,
      conditionalSubmitFlag = _ref.conditionalSubmitFlag,
      props = _objectWithoutProperties(_ref, ["nextStep", "handleNext", "buttonLabels", "getState", "handleSubmit", "isDisabled", "conditionalSubmitFlag"]);

  var nextResult = nextStep ? selectNext(nextStep, getState) : nextStep;
  var progressNext = nextResult !== conditionalSubmitFlag && nextStep;
  return /*#__PURE__*/React.createElement(Button, _extends({
    disabled: isDisabled,
    onClick: function onClick() {
      return progressNext ? handleNext(nextResult) : handleSubmit();
    },
    rightIcon: progressNext ? 'arrow-right' : 'arrow-up',
    intent: Intent.SUCCESS
  }, props), progressNext ? buttonLabels.next : buttonLabels.submit);
};

NextButton.propTypes = {
  handleNext: PropTypes.func,
  formOptions: PropTypes.shape({
    onCancel: PropTypes.func,
    renderForm: PropTypes.func,
    getState: PropTypes.func
  }),
  buttonLabels: PropTypes.object,
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.object]),
  getState: PropTypes.func,
  handleSubmit: PropTypes.func,
  isDisabled: PropTypes.bool,
  conditionalSubmitFlag: PropTypes.string.isRequired
};
var useStyles = createUseStyles({
  buttonGroup: {
    marginTop: 16,
    display: 'flex',
    justifyContent: 'space-between',
    '& button:not(:first-child)': {
      marginLeft: 8
    }
  }
});

var StepButtons = function StepButtons(_ref2) {
  var handleNext = _ref2.handleNext,
      currentStep = _ref2.currentStep,
      formOptions = _ref2.formOptions,
      activeStepIndex = _ref2.activeStepIndex,
      buttonLabels = _ref2.buttonLabels,
      handlePrev = _ref2.handlePrev,
      isNextDisabled = _ref2.isNextDisabled,
      ButtonToolbarProps = _ref2.ButtonToolbarProps,
      DirectionButtonProps = _ref2.DirectionButtonProps,
      CancelButtonProps = _ref2.CancelButtonProps,
      BackButtonProps = _ref2.BackButtonProps,
      NextButtonProps = _ref2.NextButtonProps,
      SubmitButtonProps = _ref2.SubmitButtonProps,
      conditionalSubmitFlag = _ref2.conditionalSubmitFlag;

  var _useStyles = useStyles(),
      buttonGroup = _useStyles.buttonGroup;

  return /*#__PURE__*/React.createElement("div", _extends({}, ButtonToolbarProps, {
    className: clsx(buttonGroup, ButtonToolbarProps && ButtonToolbarProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    onClick: formOptions.onCancel,
    minimal: true
  }, CancelButtonProps), buttonLabels.cancel), /*#__PURE__*/React.createElement("div", DirectionButtonProps, /*#__PURE__*/React.createElement(Button, _extends({
    onClick: handlePrev,
    disabled: activeStepIndex === 0
  }, BackButtonProps), buttonLabels.back), /*#__PURE__*/React.createElement(NextButton, _extends({
    getState: formOptions.getState,
    nextStep: currentStep.nextStep,
    buttonLabels: buttonLabels,
    handleNext: handleNext,
    isDisabled: !formOptions.valid || isNextDisabled,
    handleSubmit: formOptions.handleSubmit,
    conditionalSubmitFlag: conditionalSubmitFlag
  }, currentStep.nextStep ? NextButtonProps : SubmitButtonProps))));
};

StepButtons.propTypes = {
  currentStep: PropTypes.object,
  handlePrev: PropTypes.func,
  handleNext: PropTypes.func,
  conditionalSubmitFlag: PropTypes.string.isRequired,
  formOptions: PropTypes.shape({
    onCancel: PropTypes.func,
    renderForm: PropTypes.func,
    getState: PropTypes.func,
    handleSubmit: PropTypes.func,
    valid: PropTypes.bool
  }),
  activeStepIndex: PropTypes.number,
  buttonLabels: PropTypes.object,
  isNextDisabled: PropTypes.bool,
  ButtonToolbarProps: PropTypes.object,
  DirectionButtonProps: PropTypes.object,
  CancelButtonProps: PropTypes.object,
  BackButtonProps: PropTypes.object,
  NextButtonProps: PropTypes.object,
  SubmitButtonProps: PropTypes.object
};
export default StepButtons;
